@@ -1,18 +1,19 @@
 #!/usr/bin/perl
 
-my $RCS_Id = '$Id: Shell.pm,v 1.51 2006/01/12 21:21:10 jv Exp $ ';
+my $RCS_Id = '$Id: Shell.pm,v 1.54 2006/01/22 16:33:49 jv Exp $ ';
 
 # Author          : Johan Vromans
 # Created On      : Thu Jul  7 15:53:48 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Thu Jan 12 21:21:02 2006
-# Update Count    : 647
+# Last Modified On: Fri Jan 20 22:08:52 2006
+# Update Count    : 661
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
 
 package main;
 
+our $cfg;
 our $dbh;
 
 package EB::Shell;
@@ -42,7 +43,7 @@ sub new {
 }
 
 sub prompt {
-    my $t = $ENV{EB_DB_NAME};
+    my $t = $cfg->val(qw(database name));
     $t =~ s/^eekboek_//;
     $t = shift->{prompt} . " [$t";
     $t .= ":$bky" if defined $bky;
@@ -272,7 +273,7 @@ sub do_confirm {
 sub do_database {
     my ($self, @args) = @_;
     warn("?"._T("Te veel argumenten voor deze opdracht")."\n"), return if @args;
-    __x("Database: {db}", db => $ENV{EB_DB_NAME})
+    __x("Database: {db}", db => $cfg->val(qw(database name)));
 }
 
 ################ Service ################
@@ -792,6 +793,56 @@ Opties:
 EOS
 }
 
+################ Im/export ################
+
+sub do_export {
+    my ($self, @args) = @_;
+
+    my $opts = {
+	       };
+
+    return unless
+    parse_args(\@args,
+	       [ 'dir=s',
+		 'output=s',
+		 'boekjaar=s',
+	       ], $opts)
+      or goto &help_export;
+
+    if ( defined($opts->{dir}) && defined($opts->{output}) ) {
+	warn("?"._T("Opties --dir en --output sluiten elkaar uit")."\n");
+	return;
+    }
+    if ( !defined($opts->{dir}) && !defined($opts->{output}) ) {
+	warn("?"._T("Specifieer --dir of --output")."\n");
+	return;
+    }
+
+    return unless argcnt(@args, 0);
+
+    use EB::Export;
+    EB::Export->export($opts);
+
+    return;
+}
+
+sub help_export {
+    <<EOS;
+Exporteert de complete administratie.
+
+  export [ opties ]
+
+Opties:
+
+  --output=XXX    Selecteer uitvoerbestand
+  --dir=XXX       Selecteer uitvoerdirectory
+  --boekjaar=XX   Selecteer boekjaar
+
+Er moet of een --output of een --dir optie worden opgegeven.
+Zonder --boekjaar selectie wordt de gehele administratie gexporteerd.
+EOS
+}
+
 ################ Miscellaneous ################
 
 sub do_boekjaar {
@@ -900,6 +951,8 @@ sub do_toon {
     parse_args(\@args,
 	       [ 'btw!',
 		 'bsknr!',
+		 'bky!',
+		 'totaal!',
 		 'boekjaar=s',
 		 'verbose!',
 		 'trace!',
